@@ -33,10 +33,10 @@ impl Rotation {
 
 fn up_vector(rotation: &Transform) -> Vector<3> {
     let d = rotation.data();
-    Vector::from_components_f64([d[4], d[5], d[6]])
+    Vector::from([d[4], d[5], d[6]])
 }
 
 fn right_vector(rotation: &Transform) -> Vector<3> {
     let d = rotation.data();
-    Vector::from_components_f64([d[0], d[1], d[2]])
+    Vector::from([d[0], d[1], d[2]])
 }
